@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/accountd/accountd.c,v 1.5 2008/09/16 09:59:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/accountd/accountd.c,v 1.8 2010/07/07 16:08:14 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -20,11 +20,11 @@ static void ucase(char *s)
 
 /* ====================================================================== */
 
-/* Process line of input once authenicated */
+/* Process line of input once authenticated */
 
 static BOOL
-do_authenicated_line(struct config *config,
-                     char *line, struct iostream *stream, char *username)
+do_authenticated_line(struct config *config,
+                      char *line, struct iostream *stream, char *username)
 {
     char *cmd;
 
@@ -64,7 +64,7 @@ do_authenicated_line(struct config *config,
             ioflush(stream);
             return (NIL);
         } else if (!strcmp(cmd, "LOGIN")) {
-            ioputs(stream, "NO Already authenicated" CRLF);
+            ioputs(stream, "NO Already authenticated" CRLF);
             ioflush(stream);
             return (T);
         }
@@ -113,15 +113,15 @@ static BOOL session(struct config *config, int sockfd)
         return (NIL);
 
     if (getuid() == 0) {
-        if (!authenicate(config, stream, &username))
+        if (!authenticate(config, stream, &username))
             return (NIL);
     } else {
-        if (!authenicate_preauth(config, stream, &username))
+        if (!authenticate_preauth(config, stream, &username))
             return (NIL);
     }
 
     if (getuid() == 0) {
-        log_fatal("Authenicated session running with root privilege");
+        log_fatal("Authenticated session running with root privilege");
         /* NOTREACHED */
         exit(1);
     }
@@ -135,7 +135,7 @@ static BOOL session(struct config *config, int sockfd)
         if (buffer[0] == '\0')  /* Ignore empty lines */
             continue;
 
-        if (!do_authenicated_line(config, buffer, stream, username))
+        if (!do_authenticated_line(config, buffer, stream, username))
             break;
     }
 
@@ -150,13 +150,14 @@ static BOOL session(struct config *config, int sockfd)
 void rundaemon(struct config *config, int use_fork, int port)
 {
     struct ipaddr ipaddr;
-    int sockfd, newsockfd;
+    int *sockfds;
+    int newsockfd;
     pid_t childpid;
 #ifdef USE_SSL
     struct ssl_config ssl_config;
 #endif
 
-    if ((sockfd = os_bind_inet_socket(port, NIL)) < 0)
+    if (!(sockfds = os_bind_inet_socket(port, NIL)))
         log_fatal("socket() failed");
 
     os_signal_child_init(os_child_reaper);
@@ -169,29 +170,53 @@ void rundaemon(struct config *config, int use_fork, int port)
 #endif
 
     for (;;) {
-        if ((newsockfd = os_accept_inet(sockfd, &ipaddr)) < 0)
-            log_fatal("accept() failed: errno = %d", errno);
+        fd_set fds;
+        int maxsockfd, i;
 
-        log_misc("Incoming connection from %s", ipaddr_text(&ipaddr));
+        FD_ZERO(&fds);
+        maxsockfd = 0;
+        for (i=0; sockfds[i] >= 0; i++) {
+            FD_SET(sockfds[i], &fds);
 
-        if (use_fork) {
-            if ((childpid = fork()) < 0)
-                log_fatal("fork() failed: errno = %d", errno);
+            if (sockfds[0] > maxsockfd)
+                maxsockfd = sockfds[0];
+        }
 
-            if (childpid == 0) {
-                /* Child process */
-                close(sockfd);
-                os_signal_child_clear();
+        while (select(maxsockfd + 1, &fds, NIL, NIL, NIL) < 0) {
+            if (errno != EINTR)
+                log_fatal("prayer_server(): select() failed: %s",
+                          strerror(errno));
+        }
 
-                session(config, newsockfd);
+        for (i=0; sockfds[i] >= 0; i++) {
+            if (FD_ISSET(sockfds[i], &fds)) {
+                int sockfd = sockfds[i];
+
+                if ((newsockfd = os_accept_inet(sockfd, &ipaddr)) < 0)
+                    log_fatal("accept() failed: errno = %d", errno);
+
+                log_misc("Incoming connection from %s", ipaddr_text(&ipaddr));
+
+                if (use_fork) {
+                    if ((childpid = fork()) < 0)
+                        log_fatal("fork() failed: errno = %d", errno);
+                    
+                    if (childpid == 0) {
+                        /* Child process */
+                        close(sockfd);
+                        os_signal_child_clear();
+
+                        session(config, newsockfd);
+                        close(newsockfd);
+                        exit(0);
+                    }
+                } else
+                    session(config, newsockfd);
+
+                /* Parent */
                 close(newsockfd);
-                exit(0);
             }
-        } else
-            session(config, newsockfd);
-
-        /* Parent */
-        close(newsockfd);
+        }
 
 #ifdef USE_SSL
         /* Replace (shared) RSA key every few minutes */
