@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/accountd/accountd.h,v 1.3 2008/09/16 09:59:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/accountd/accountd.h,v 1.4 2009/09/28 10:17:27 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -49,4 +49,4 @@ extern int errno;
 #include "mail.h"
 #include "filter.h"
 #include "checksum.h"
-#include "authenicate.h"
+#include "authenticate.h"
