@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/accountd/authenticate.c,v 1.4 2009/09/01 10:35:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/accountd/authenticate.c,v 1.6 2009/09/28 10:17:27 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -8,8 +8,16 @@
 
 #include "accountd.h"
 
+#ifdef BSD4_4
+#define HAVE_SHADOW 0
+#else
+#define HAVE_SHADOW 1
+#endif
+
 #include <pwd.h>
+#if HAVE_SHADOW
 #include <shadow.h>
+#endif
 
 /* ====================================================================== */
 
@@ -83,15 +91,17 @@ static int checkpassword_raven(struct config *config,
 #endif
 /* ====================================================================== */
 
-/* Code for authenicating user across iostream connection to client.
+/* Code for authenticating user across iostream connection to client.
  * User interaction involving a root process: important that this code is
  * protected and properly verified! */
 
-/* Definies a whole series of different authenication methods, including
+/* Definies a whole series of different authentication methods, including
  * PAM if PAM support configured in ../Config */
 
 /* No prototype for crypt, at least on Linux */
+#if HAVE_SHADOW
 extern char *crypt(char *password, char *salt);
+#endif
 
 /* ====================================================================== */
 
@@ -148,7 +158,7 @@ static int checkpassword_pam(char *username, char *password)
 #else
 static int checkpassword_pam(char *username, char *password)
 {
-    log_panic("PAM authenication selected but support not compiled in");
+    log_panic("PAM authentication selected but support not compiled in");
     return (NIL);
 }
 #endif
@@ -159,6 +169,7 @@ static int checkpassword_pam(char *username, char *password)
  * (we don't use them)
  */
 
+#if HAVE_SHADOW
 static int checkpassword_spnam(char *username, char *password, int md5)
 {
     struct spwd *spwd;
@@ -188,6 +199,7 @@ static int checkpassword_spnam(char *username, char *password, int md5)
     endspent();
     return (rc);
 }
+#endif
 
 static int checkpassword_pwnam(char *username, char *password, int md5)
 {
@@ -215,7 +227,7 @@ static int checkpassword_pwnam(char *username, char *password, int md5)
             rc = NIL;
     }
 
-    endspent();
+    endpwent();
     return (rc);
 }
 
@@ -229,9 +241,9 @@ static void ucase(char *s)
     }
 }
 
-/* authenicate() *********************************************************
+/* authenticate() *********************************************************
  *
- * Authenicate login session and drop priveledges.
+ * Authenticate login session and drop priveledges.
  *     config:  Global configuration
  *     stream:  iostream connection to client
  *   usernamep: Used to return username of logged in user
@@ -240,7 +252,7 @@ static void ucase(char *s)
  ************************************************************************/
 
 BOOL
-authenicate(struct config *config, struct iostream *stream,
+authenticate(struct config *config, struct iostream *stream,
             char **usernamep)
 {
     char buffer[MAXLENGTH];
@@ -253,7 +265,7 @@ authenicate(struct config *config, struct iostream *stream,
     *usernamep = NIL;
 
     if (getuid() != 0)
-        log_fatal("authenicate(): called without root priveledges");
+        log_fatal("authenticate(): called without root priveledges");
 
     ioputs(stream, "* ");
     if (config->filter_restricted)
@@ -309,7 +321,7 @@ authenicate(struct config *config, struct iostream *stream,
         if (!(username && username[0] && password && password[0]))
             continue;
 
-        /* Only need to authenicate if root */
+        /* Only need to authenticate if root */
         if (config->raven_enable && (strlen(password) > 256)) {
             rc = checkpassword_raven(config, username, password);
         } else switch (config->authtype) {
@@ -322,28 +334,30 @@ authenicate(struct config *config, struct iostream *stream,
         case AUTHTYPE_PWD_MD5:
             rc = checkpassword_pwnam(username, password, 1);
             break;
+#if HAVE_SHADOW
         case AUTHTYPE_SHADOW:
             rc = checkpassword_spnam(username, password, 0);
             break;
         case AUTHTYPE_SHADOW_MD5:
             rc = checkpassword_spnam(username, password, 1);
             break;
+#endif
         default:
-            log_fatal("Unsupported authenication type");
+            log_fatal("Unsupported authentication type");
         }
 
         if (!rc) {
-            ioputs(stream, "NO Incorrect authenication" CRLF);
+            ioputs(stream, "NO Incorrect authentication" CRLF);
             ioflush(stream);
-            log_misc("Incorrect authenication for: %s", username);
+            log_misc("Incorrect authentication for: %s", username);
             continue;
         }
 
-        /* getpwnam() shouldn't fail if PAM authenication working properly */
+        /* getpwnam() shouldn't fail if PAM authentication working properly */
         if ((pwd = getpwnam(username)) == NIL) {
-            ioputs(stream, "NO Incorrect authenication" CRLF);
+            ioputs(stream, "NO Incorrect authentication" CRLF);
             ioflush(stream);
-            log_misc("Incorrect authenication for: %s", username);
+            log_misc("Incorrect authentication for: %s", username);
             continue;
         }
 
@@ -364,11 +378,11 @@ authenicate(struct config *config, struct iostream *stream,
         return (NIL);
     }
 
-    ioputs(stream, "OK Session authenicated" CRLF);
+    ioputs(stream, "OK Session authenticated" CRLF);
     ioflush(stream);
 
     if (getuid() == 0)
-        log_fatal("authenicate(): Ended up as root user!");
+        log_fatal("authenticate(): Ended up as root user!");
 
     *usernamep = strdup(username);
     return (T);
@@ -376,9 +390,9 @@ authenicate(struct config *config, struct iostream *stream,
 
 /* ====================================================================== */
 
-/* authenicate_preauth() *************************************************
+/* authenticate_preauth() ************************************************
  *
- * Authenicate login session and drop priveledges.
+ * Authenticate login session and drop priveledges.
  *     config:  Global configuration
  *     stream:  iostream connection to client
  *   usernamep: Used to return username of logged in user
@@ -387,13 +401,13 @@ authenicate(struct config *config, struct iostream *stream,
  ************************************************************************/
 
 BOOL
-authenicate_preauth(struct config * config,
-                    struct iostream * stream, char **usernamep)
+authenticate_preauth(struct config * config,
+                     struct iostream * stream, char **usernamep)
 {
     struct passwd *pwd;
 
     if (getuid() == 0)
-        log_fatal("authenicate_preauth(): called as root");
+        log_fatal("authenticate_preauth(): called as root");
 
     if ((pwd = getpwuid(getuid())) == NIL)
         log_fatal("session(): getpwuid() failed");
