@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/accountd/config.c,v 1.4 2008/05/19 15:55:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/accountd/config.c,v 1.5 2008/09/16 09:59:54 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -24,6 +24,8 @@ struct config *config_create(void)
     config->log_debug = NIL;
     config->child_timeout = 10 * 60;
     config->authtype = AUTHTYPE_UNKNOWN;
+    config->raven_enable = NIL;
+    config->raven_key_path = "";
 
     /* Location of filter files */
     config->msforward_name = ".MSforward";
@@ -130,6 +132,8 @@ static struct {
     "pwd_script", config_string, OFFSET(pwd_script)}, {
     "quota_cmdline", config_string, OFFSET(quota_cmdline)}, {
     "quota_hermes", config_bool, OFFSET(quota_hermes)}, {
+    "raven_enable", config_bool, OFFSET(raven_enable)}, {
+    "raven_key_path", config_path, OFFSET(raven_key_path)}, {
     "ssl_cert_file", config_path, OFFSET(ssl_cert_file)}, {
     "ssl_dh_file", config_path, OFFSET(ssl_dh_file)}, {
     "ssl_privatekey_file", config_path, OFFSET(ssl_privatekey_file)}, {
