@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_export.c,v 1.2 2008/05/19 15:55:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_export.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -19,7 +19,7 @@ void cmd_abook_export(struct session *session)
     char *abook_text = abook_export_text(abook, request->pool);
 
     if (!account_abook_put(account, request->pool, abook_text)) {
-        session_message(session, "Failed to export addressbook");
+        session_alert(session, "Failed to export addressbook");
         session_redirect(session, request, "abook_xfer");
     } else {
         session_message(session, "Addressbook exported to Hermes");
