@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_import.c,v 1.2 2008/05/19 15:55:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_import.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -19,13 +19,13 @@ void cmd_abook_import(struct session *session)
 
     /* Fetch .addressbook from account server */
     if (!(text = account_abook_get(session->account, request->pool))) {
-        session_message(session, "Unable to download addressbook file");
+        session_alert(session, "Unable to download addressbook file");
         session_redirect(session, request, "abook_xfer");
         return;
     }
 
     if (!abook_import_pine_valid(text)) {
-        session_message(session, "Invalid/Unsupported addressbook format");
+        session_alert(session, "Invalid/Unsupported addressbook format");
         session_redirect(session, request, "abook_list");
         return;
     }
