@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_list.c,v 1.3 2008/09/16 09:59:55 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_list.c,v 1.4 2011/11/09 14:44:20 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -153,7 +153,8 @@ cmd_abook_list_single(struct template_vals *tvals,
     template_vals_foreach_string(tvals, "@abook", i, "alias", abe->alias);
     template_vals_foreach_string(tvals, "@abook", i, "name", abe->name);
     template_vals_foreach_string(tvals, "@abook", i, "comment", abe->comment);
-    template_vals_foreach_string(tvals, "@abook", i, "email", abe->email);
+    template_vals_foreach_string(tvals, "@abook", i, "email",
+                                 string_email_split(tvals->pool, abe->email));
     if (i % 2 == 0)
         template_vals_foreach_ulong(tvals, "@abook", i, "even_row", 1);
 }
