@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_search.c,v 1.3 2008/09/16 09:59:55 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_abook_search.c,v 1.4 2011/11/09 14:44:20 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -124,8 +124,11 @@ generate_form(struct session *session, struct abook_search_list *asl,
                                          "name", abe->name);
             template_vals_foreach_string(tvals, "@results", i,
                                          "comment", abe->comment);
-            template_vals_foreach_string(tvals, "@results", i,
-                                         "email", abe->email);
+            template_vals_foreach_string
+                (tvals, "@results", i, "email",
+                 string_email_split(tvals->pool,abe->email));
+                                    
+
             i++;
         }
     }
