@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_check_cookie.c,v 1.3 2008/09/16 09:59:55 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_check_cookie.c,v 1.5 2010/07/07 15:49:34 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -10,19 +10,16 @@
 
 void cmd_check_cookie(struct session *session)
 {
-    struct config *config = session->config;
     struct request *request = session->request;
     char *s = assoc_lookup(request->hdrs, "cookie");
     char *t;
     char *u;
     BOOL have_cookie = NIL;
     char *key;
+    unsigned long pid = (unsigned long)getpid();
 
-    if (config->http_cookie_use_port)
-        key = pool_printf(request->pool, "%s:%lu",
-                          session->username, session->session_port);
-    else
-        key = session->username;
+    key = pool_printf(request->pool, "%s:%lu", session->username, pid);
+                      
 
     /* Look for username:port=VALUE in cookie */
     while (s && *s && (t = strchr(s, '='))) {
