@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_download.c,v 1.3 2008/09/16 09:59:55 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_download.c,v 1.4 2010/07/07 15:49:34 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -8,18 +8,6 @@
 
 #include "prayer_session.h"
 
-/* Small utility routine stolen from PINE */
-
-static STRINGLIST *new_strlst(char **l)
-{
-    STRINGLIST *sl = mail_newstringlist();
-
-    sl->text.data = (unsigned char *) (*l);
-    sl->text.size = strlen(*l);
-    sl->next = (*++l) ? new_strlst(l) : NULL;
-    return (sl);
-}
-
 /* ====================================================================== */
 
 void cmd_download(struct session *session)
