@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_download_xfer.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_download_xfer.c,v 1.5 2009/12/01 17:01:15 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -25,7 +25,6 @@ static BOOL download(struct session *session, char *name)
     MESSAGECACHE *elt;
     ENVELOPE *env;
     ADDRESS *addr;
-    time_t now = time(NIL);
     int flag;
     char tmp[MAILTMPLEN];
     unsigned long uid;
@@ -88,11 +87,13 @@ static BOOL download(struct session *session, char *name)
               (env = ml_fetch_structure(session, tstream, msgno, NIL, 0))))
             return (NIL);
 
+        mail_cdate (tmp, elt);
+
         if ((addr = env->sender) && addr->mailbox && addr->host)
             bprintf(b, "From %s@%s %s", addr->mailbox, addr->host,
-                    ctime(&now));
+                    tmp);
         else
-            bprintf(b, "From unknown@nowhere.com %s", ctime(&now));
+            bprintf(b, "From unknown@nowhere.com %s", tmp);
 
 
         if (!
