@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_forward1.c,v 1.11 2011/01/17 20:28:27 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_forward1.c,v 1.12 2012/04/30 14:54:09 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -36,7 +36,7 @@ static BOOL
 add_attachments(struct session *session,
                 struct draft *draft,
                 struct pool *pool, MAILSTREAM * stream,
-                unsigned long msgno)
+                unsigned long msgno, BOOL attach_first)
 {
     BODY *body;
     PART *part;
@@ -78,9 +78,15 @@ add_attachments(struct session *session,
     if (!(part = body->nested.part))
         return (T);
     
-    /* First part is always text message displayed to user: skip overit  */
-    part = part->next;
-    section = 2;
+    /* First part is typically text part displayed to user. Skip it unless
+       we were unable to extract text part to display inline (add_text) */
+
+    if (attach_first) {
+        section = 1;
+    } else {
+        section = 2;
+        part = part->next;
+    }
 
     while (part) {
         char *stext = string_itoa(pool, section);
@@ -158,7 +164,8 @@ static BOOL
 add_text(struct session *session,
          struct buffer *b,
          STRINGLIST * hdrslist,
-         struct pool *pool, MAILSTREAM * stream, unsigned long msgno)
+         struct pool *pool, MAILSTREAM * stream, unsigned long msgno,
+         BOOL *attach_first)
 {
     struct options *options = session->options;
     struct prefs *prefs = options->prefs;
@@ -170,6 +177,8 @@ add_text(struct session *session,
     PARAMETER *parameter;
     char *charset = "ISO-8859-1";
 
+    *attach_first = NIL;
+
     if (!(text = ml_fetch_header(session, stream, msgno,
                                  NIL, hdrslist, &len, 0)))
         return (NIL);
@@ -204,14 +213,16 @@ add_text(struct session *session,
         subsection = (body_plain) ? body_plain : body_html;
 
         if (!subsection) {
-            bputs(b, "(Message body was not text: suppressed)" CRLF);
+            bputs(b, "(Message body included as attachment)" CRLF);
+            *attach_first = T;
             return(T);
         }
         section = pool_printf(pool, "1.%lu", subsection);
         if ((body = ml_body(session, stream, msgno, section)) == NIL)
             return (NIL);
     } else if (body->type != TYPETEXT) {
-        bputs(b, "(Message body was not text: suppressed)" CRLF);
+        bputs(b, "(Message body included as attachment)" CRLF);
+        *attach_first = T;
         return (T);
     } else
         section = "1";
@@ -343,19 +354,20 @@ void cmd_forward1(struct session *session)
 
     if (!session->aggregate) {
         /* Simple forward */
+        BOOL attach_first = NIL;
 
         bprintf(b, CRLF "---------- Forwarded message ----------" CRLF);
 
         /* Add message text */
         if (!add_text(session, b, hdrslist, request->pool,
-                      stream, session->current)) {
+                      stream, session->current, &attach_first)) {
             session_redirect(session, request, "restart");
             return;
         }
 
         /* Add attachments if multipart message */
         if (!add_attachments(session, draft, request->pool,
-                             stream, session->current)) {
+                             stream, session->current, attach_first)) {
             session_redirect(session, request, "restart");
             return;
         }
@@ -455,6 +467,7 @@ void cmd_forward1(struct session *session)
     for (offset = 1L; offset <= msgmap_size(zm); offset++) {
         unsigned long msgno = msgmap_value(zm, offset);
         BOOL forward_this;
+        BOOL attach_first = NIL;
 
         if (prefs->use_mark_persist && msgmap_has_mark(zm, msgno))
             forward_this = T;
@@ -472,7 +485,8 @@ void cmd_forward1(struct session *session)
                         ++count2);
 
             if (!add_text
-                (session, b, hdrslist, request->pool, stream, msgno)) {
+                (session, b, hdrslist, request->pool, stream, msgno,
+                 &attach_first)) {
                 session_redirect(session, request, "restart");
                 return;
             }
@@ -482,7 +496,7 @@ void cmd_forward1(struct session *session)
 
             /* Add attachments if multipart message */
             if (!add_attachments
-                (session, draft, request->pool, stream, msgno)) {
+                (session, draft, request->pool, stream, msgno, attach_first)) {
                 session_redirect(session, request, "restart");
                 return;
             }
