@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_list.c,v 1.5 2008/09/18 08:50:11 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_list.c,v 1.6 2011/04/26 09:33:14 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -204,7 +204,7 @@ cmd_list_msg(struct session *session,
      * Yes => show "To:" rather than from address in header.
      */
     use_to = NIL;
-    if ((addr = env->from)) {
+    if ((addr = env->from) && addr->host) {
         while (alt_addr) {
             if (!strcasecmp(addr->mailbox, alt_addr->mailbox) &&
                 !strcasecmp(addr->host, alt_addr->host)) {
