@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_prefs.c,v 1.2 2008/05/19 15:55:54 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_prefs.c,v 1.4 2008/09/26 09:58:05 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -20,6 +20,24 @@ generate_general_form(struct session *session, struct prefs *prefs)
     struct request *request = session->request;
     struct buffer *b = request->write_buffer;
 
+    template_vals_string(tvals, "template_set", prefs->template_set);
+
+    if (config->template_list) {
+        unsigned long offset = 0;
+        struct list_item *li;
+
+        for (li = config->template_list->head; li; li = li->next) {
+            struct config_template *template = (struct config_template *) li;
+
+            template_vals_foreach_init(tvals, "@templates", offset);
+            template_vals_foreach_string(tvals, "@templates", offset,
+                                         "name", template->name);
+            template_vals_foreach_string(tvals, "@templates", offset,
+                                         "fullname", template->description);
+            offset++;
+        }
+    }
+
     template_vals_string(tvals, "theme_main_name", prefs->theme_main_name);
     template_vals_string(tvals, "theme_help_name", prefs->theme_help_name);
     if (config->theme_list && (list_length(config->theme_list) > 1)) {
@@ -41,12 +59,21 @@ generate_general_form(struct session *session, struct prefs *prefs)
     if (prefs->use_welcome)
         template_vals_ulong(tvals, "use_welcome", 1);
 
+    if (config->raven_enable)
+        template_vals_ulong(tvals, "raven_enable", 1);
+
+    if (prefs->allow_raven_login)
+        template_vals_ulong(tvals, "allow_raven_login", 1);
+
     if (prefs->confirm_expunge)
         template_vals_ulong(tvals, "confirm_expunge", 1);
 
     if (prefs->confirm_logout)
         template_vals_ulong(tvals, "confirm_logout", 1);
 
+    if (prefs->expunge_on_exit)
+        template_vals_ulong(tvals, "expunge_on_exit", 1);
+
     if (prefs->use_mark_persist)
        template_vals_ulong(tvals, "use_mark_persist", 1);
 
@@ -64,13 +91,20 @@ static BOOL
 process_general_prefs(struct session *session,
                       struct prefs *prefs, struct assoc *h)
 {
+    struct config *config = session->config;
     char *s;
 
-    if ((s = assoc_lookup(h, "theme_main_name"))) {
+    if ((s = assoc_lookup(h, "template_set")) && s[0]) {
+        if (config->template_list &&
+            list_lookup_byname(config->template_list, s))
+            prefs->template_set = pool_strdup(prefs->pool, s);
+    }
+
+    if ((s = assoc_lookup(h, "theme_main_name")) && s[0]) {
         prefs->theme_main_name = pool_strdup(prefs->pool, s);
     }
 
-    if ((s = assoc_lookup(h, "theme_help_name"))) {
+    if ((s = assoc_lookup(h, "theme_help_name")) && s[0]) {
         prefs->theme_help_name = pool_strdup(prefs->pool, s);
     }
 
@@ -80,8 +114,15 @@ process_general_prefs(struct session *session,
     prefs->use_search_zoom =
         (assoc_lookup(h, "use_search_zoom")) ? T : NIL;
     prefs->use_agg_unmark = (assoc_lookup(h, "use_agg_unmark")) ? T : NIL;
+
+    if (config->raven_enable) {
+        prefs->allow_raven_login
+            = (assoc_lookup(h, "allow_raven_login")) ? T : NIL;
+    }
+
     prefs->confirm_expunge = (assoc_lookup(h, "confirm_expunge")) ? T : NIL;
     prefs->confirm_logout = (assoc_lookup(h, "confirm_logout")) ? T : NIL;
+    prefs->expunge_on_exit = (assoc_lookup(h, "expunge_on_exit")) ? T : NIL;
 
     return (T);
 }
@@ -113,9 +154,15 @@ generate_display_form(struct session *session, struct prefs *prefs)
     if (prefs->html_inline_auto)
        template_vals_ulong(tvals, "html_inline_auto", 1);
 
+    if (prefs->html_remote_images)
+       template_vals_ulong(tvals, "html_remote_images", 1);
+
     if (prefs->preserve_mimetype)
        template_vals_ulong(tvals, "preserve_mimetype", 1);
 
+    if (prefs->use_unread)
+       template_vals_ulong(tvals, "use_unread", 1);
+
     switch (sort_mode) {
     case ARRIVAL:
         template_vals_string(tvals, "folder_sort_mode",
@@ -277,8 +324,12 @@ process_display_prefs(struct session *session,
     prefs->html_inline = (assoc_lookup(h, "html_inline")) ? T : NIL;
     prefs->html_inline_auto =
         (assoc_lookup(h, "html_inline_auto")) ? T : NIL;
+    prefs->html_remote_images =
+        (assoc_lookup(h, "html_remote_images")) ? T : NIL;
     prefs->preserve_mimetype =
         (assoc_lookup(h, "preserve_mimetype")) ? T : NIL;
+    prefs->use_unread =
+        (assoc_lookup(h, "use_unread")) ? T : NIL;
 
     if ((s = assoc_lookup(h, "folder_sort_mode"))) {
         if (!strncmp(s, "reverse-", strlen("reverse-"))) {
@@ -474,9 +525,12 @@ generate_compose1_form(struct session *session, struct prefs *prefs)
     template_vals_string(tvals, "from_address", prefs->from_address);
 
     if (!(prefs->from_address && prefs->from_address[0])) {
-        char *s = pool_printf(request->pool, "%s@%s",
-                              session->username, prefs->default_domain);
+        char *s = session->username;
 
+        if (!strchr(session->username, '@')) {
+            s = pool_printf(request->pool, "%s@%s",
+                            session->username, prefs->default_domain);
+        }
         template_vals_string(tvals, "default_from_address", s);
     }
 
