@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_sieve.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_sieve.c,v 1.5 2012/02/14 13:55:46 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -286,7 +286,9 @@ void cmd_sieve(struct session *session)
         sieve_current_record(sieve, NIL);
 
         if (sieve_live(sieve)) {
-            if (sieve_delete(sieve, session, "sieve")) {
+            /* Need to deactivate sieve file before deleting with Cyrus 2.4 */
+            if (sieve_activate(sieve, session, "") &&
+                sieve_delete(sieve, session, "sieve")) {
                 session_message(session, "Removed sieve filter");
                 sieve_live_record(sieve, NIL);
             } else
