@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_vacation.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_vacation.c,v 1.5 2010/07/02 08:31:08 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -14,13 +14,17 @@ static void generate_form(struct session *session)
     struct request *request = session->request;
     struct buffer *b = request->write_buffer;
     struct account *account = session->account;
-    char *aliases = ((account->vacation_aliases)
-                     ? (account->vacation_aliases) : NIL);
+    char *aliases = account->vacation_aliases;
+    char *subject = account->vacation_subject;
+
+    if (!(subject && subject[0]))
+        subject = "Auto-Response: Vacation Message";
 
     if (account->vacation_enabled)
         template_vals_ulong(tvals, "use_vacation", 1);
     
     template_vals_string(tvals, "aliases", aliases);
+    template_vals_string(tvals, "subject", subject);
     template_vals_ulong(tvals, "days", account->vacation_days);
 
     if (session->sieved_server)
@@ -117,6 +121,11 @@ void cmd_vacation(struct session *session)
     } else
         string_strdup(&account->vacation_aliases, "");
 
+    if ((s = assoc_lookup(h, "subject")))
+        string_strdup(&account->vacation_subject, s);
+    else
+        string_strdup(&account->vacation_subject, "");
+
     if (rc) {
         if (account_vacation_update(account, request->pool) &&
             account_mail_update(account, request->pool)) {
