@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_welcome.c,v 1.3 2008/06/24 14:40:49 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_welcome.c,v 1.5 2008/10/31 10:55:19 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -8,7 +8,7 @@
 
 #include "prayer_session.h"
 
-static void generate_welcome_page(struct session *session, char *string)
+static void generate_welcome_page(struct session *session)
 {
     struct template_vals *tvals = session->template_vals;
     struct pool *pool = tvals->pool;
@@ -38,15 +38,13 @@ static void generate_welcome_page(struct session *session, char *string)
 
 void cmd_welcome(struct session *session)
 {
-    struct config *config = session->config;
     struct options *options = session->options;
     struct prefs *prefs = options->prefs;
     struct request *request = session->request;
-    char *string;
     unsigned long msgno;
 
     if ((request->method != POST) && (prefs->use_welcome)) {
-        generate_welcome_page(session, string);
+        generate_welcome_page(session);
         return;
     }
 
@@ -62,8 +60,10 @@ void cmd_welcome(struct session *session)
     msgno = stream_find_unread(session, session->stream);
 
     if (msgno > 0) {
-        session->current = msgno;
-        session->last_displayed = msgno;
+        if (prefs->use_unread) {
+            session->current = msgno;
+            session->last_displayed = msgno;
+        }
         session_message(session, "First unread message: %lu", msgno);
     } else
         session_message(session, "No unread messages in inbox");
