@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/ipaddr.h,v 1.2 2008/05/19 15:55:56 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/ipaddr.h,v 1.4 2009/08/20 12:37:55 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -8,7 +8,7 @@
 
 struct ipaddr {
     unsigned long version;
-    unsigned long addr[4];
+    unsigned char addr[16];
 };
 
 struct ipaddr *ipaddr_create(struct pool *pool);
