@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/lib.h,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/lib.h,v 1.4 2010/07/07 08:52:14 dpc22 Exp $ */
 
 /************************************************
  *    Prayer - a Webmail Interface              *
@@ -36,7 +36,8 @@
 #include "list.h"
 #include "memblock.h"
 #include "template_vals.h"
-#include "template.h"
+#include "template_structs.h"
+#include "template_fns.h"
 #include "mystring.h"
 #include "ssl.h"
 #include "iostream.h"
