@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/mymutex.c,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/mymutex.c,v 1.4 2009/10/16 14:56:29 dpc22 Exp $ */
 
 /************************************************
  *    Prayer - a Webmail Interface              *
@@ -9,7 +9,7 @@
 
 #include "lib.h"
 
-#ifdef MUTEX_SEMAPHORE
+#if defined(MUTEX_SEMAPHORE) && !defined(__stub_semtimedop)
 #  include "mymutex_sem.c"
 #else
 #  include "mymutex_file.c"
