@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/mystring.c,v 1.4 2009/04/09 10:31:38 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/mystring.c,v 1.6 2012/01/08 20:18:27 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -1480,3 +1480,39 @@ string_strip_crlf(char *s)
     }
     *d = '\0';
 }
+
+/* ====================================================================== */
+
+/* Render "a,b,c" as "a, b, c" so the browser can wrap */
+
+static int
+string_email_split_len(char *s)
+{
+    int len = 0;
+
+    while (*s) {
+        len += (s[0] == ',' && !string_isspace(s[1])) ? 2 : 1;
+        s++;
+    }
+
+    return(len);
+}
+
+char *
+string_email_split(struct pool *pool, char *s)
+{
+    char *result = pool_alloc(pool, string_email_split_len(s)+1);
+    char *t = result;
+
+    while (*s) {
+        if (s[0] == ',' && !string_isspace(s[1])) {
+            *t++ = *s++;
+            *t++ = ' ';
+        } else {
+            *t++ = *s++;
+        }
+    }
+    *t = '\0';
+    return(result);
+}
+
