@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/os.c,v 1.8 2011/01/18 13:32:50 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/os.c,v 1.9 2011/06/28 07:39:18 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -220,11 +220,11 @@ int *os_bind_inet_socket(unsigned long port, char *interface)
 #ifdef IPV6_V6ONLY
         if (ai->ai_family == AF_INET6) {
             /* Linux refuses to bind to both '0.0.0.0' and '::' without
-               IPPROTO_IPV6. Alternative approach would be to reorder the
-               list so that '::' appears first and only try binding to
+               IPV6_V6ONLY option. Alternative approach would be to reorder
+               the list so that '::' appears first and only try binding to
                '0.0.0.0' if '::' fails. Exim daemon.c has long explanation.
 
-               IPPROTO_IPV6 is good enough for our needs on Hermes */
+               IPV6_V6ONLY is good enough for our needs on Hermes */
 
             /* Ignore errors here */
             optval = 1;
