@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/os.h,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/os.h,v 1.4 2010/07/07 15:02:10 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -14,7 +14,7 @@ int os_connect_inet_socket(char *host, unsigned long port);
 
 int os_bind_unix_socket(char *name);
 
-int os_bind_inet_socket(unsigned long port, char *interface);
+int *os_bind_inet_socket(unsigned long port, char *interface);
 
 int os_accept_unix(int sockfd);
 
