@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/ssl.c,v 1.6 2009/10/08 14:27:14 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/ssl.c,v 1.8 2012/06/30 14:30:08 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -41,12 +41,6 @@ static unsigned char *sid_ctx = (unsigned char *) "Prayer SID";
 /* Enable full logging? */
 static BOOL ssl_verbose_logging = NIL;
 
-/* RSA key length */
-#define SSL_RSA_KEYLENGTH   (1024)
-
-/* Cipher list */
-#define SSLCIPHERLIST "ALL:!ADH:RC4+RSA:+HIGH:+MEDIUM:+LOW:!SSLv2:!EXP"
-
 /* ====================================================================== */
 
 /* PRNG stuff for SSL */
@@ -377,6 +371,12 @@ static SSL_SESSION *get_session_cb(SSL * ssl, unsigned char *id, int idlen,
 
 void ssl_context_init(struct ssl_config *ssl_config)
 {
+    char *ssl_cipher_list = SSLCIPHERLIST_DEFAULT;
+
+    /* Set cipherlist */
+    if (ssl_config->ssl_cipher_list && ssl_config->ssl_cipher_list[0])
+        ssl_cipher_list = ssl_config->ssl_cipher_list;
+
     /* Set up random number generator */
     os_initialize_prng(ssl_config);
 
@@ -402,10 +402,10 @@ void ssl_context_init(struct ssl_config *ssl_config)
     SSL_CTX_set_session_cache_mode(client_ctx, SSL_SESS_CACHE_OFF);
     SSL_CTX_set_timeout(client_ctx, 0);
 
-    /* Set cipherlist */
-    if (!SSL_CTX_set_cipher_list(client_ctx, SSLCIPHERLIST))
+    if (!SSL_CTX_set_cipher_list(client_ctx, ssl_cipher_list))
         log_fatal("SSL_CTX_set_cipher_list");
 
+
     /* Set up server context */
     server_ctx = SSL_CTX_new(SSLv23_server_method());
 
@@ -494,9 +494,15 @@ void ssl_context_init(struct ssl_config *ssl_config)
              ssl_config->ssl_privatekey_file);
 
     /* Set cipherlist */
-    if (!SSL_CTX_set_cipher_list(server_ctx, SSLCIPHERLIST))
+    if (!SSL_CTX_set_cipher_list(server_ctx, ssl_cipher_list))
         log_fatal("SSL_CTX_set_cipher_list() failed");
 
+    /* Make server rather than client pick preferred cipher */
+    if (ssl_config->ssl_server_preference &&
+        !SSL_CTX_set_options(server_ctx, SSL_OP_CIPHER_SERVER_PREFERENCE))
+        log_fatal("SSL_CTX_set_options(SSL_OP_CIPHER_SERVER_PREFERENCE)"
+                  "failed");
+
     /* Set up RSA temporary key callback routine */
     if (SSL_CTX_need_tmp_RSA(server_ctx))
         SSL_CTX_set_tmp_rsa_callback(server_ctx, rsa_callback);
