@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/ssl.h,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/ssl.h,v 1.4 2012/06/30 14:30:08 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -10,9 +10,18 @@
 #define SSL_PRAYER_RETRY (-2)
 #define SSL_PRAYER_ERROR (-1)
 
+/* RSA key length */
+#define SSL_RSA_KEYLENGTH   (1024)
+
+/* Default Cipher list */
+#define SSLCIPHERLIST_DEFAULT \
+    "ECDHE-RSA-AES128-SHA256:AES128-GCM-SHA256:RC4:HIGH:!MD5:!aNULL:!EDH:!EXP"
+
 /* Subset of struct config which is relevant to SSL */
 
 struct ssl_config {
+    char *ssl_cipher_list;       /* List of ciphers */
+    BOOL  ssl_server_preference; /* Server selects preferred cipher */
     char *ssl_session_dir;      /* SSL session directory */
     char *ssl_cert_file;        /* SSL Certificate file              */
     char *ssl_privatekey_file;  /* SSL Privatekey file               */
