@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/template_compile.c,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/template_compile.c,v 1.4 2010/07/07 08:52:14 dpc22 Exp $ */
 
 /************************************************
  *    Prayer - a Webmail Interface              *
@@ -79,7 +79,7 @@ template_compile_lines(struct template_lines *item, FILE *file)
         p++;
         count--;
     }
-    fprintf(file, "  NULL\n");
+    fprintf(file, "  NIL\n");
     fprintf(file, "};\n\n");
 
     fprintf(file, "static struct template_lines _t%lu = {\n", item->number);
@@ -236,7 +236,8 @@ template_compile_interface(char *prefix, struct template *template, FILE *file)
 BOOL
 template_compile(char *prefix, struct template *template, FILE *file)
 {
-    fprintf(file, "#include \"lib.h\"\n\n");
+    fprintf(file, "#include \"misc.h\"\n");
+    fprintf(file, "#include \"template_structs.h\"\n\n");
     template_compile_decls(template, file);
     template_compile_data(template, file);
     template_compile_interface(prefix, template, file);
