@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/servers/portlist.c,v 1.3 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/servers/portlist.c,v 1.4 2010/07/07 10:30:09 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -50,47 +50,6 @@ void portlist_free(struct portlist *pl)
 
 /* ====================================================================== */
 
-/* portlist_reserve_port() ***********************************************
- *
- * Reserve a port from the given list, either from idle list or free range
- *   pl: Portlist
- *
- * Returns: Ptr to port structure (allocated automatically if needed)
- ***********************************************************************/
-
-struct port *portlist_reserve_port(struct portlist *pl)
-{
-    struct port *port;
-    unsigned long inet_port;
-    int sockfd;
-
-    if (list_length(pl->idle) > 0) {
-        struct list_item *li = list_shift(pl->idle);
-        list_unshift(pl->active, li, NIL);
-
-        return ((struct port *) li);
-    }
-
-    if (pl->next > pl->last)
-        return (NIL);
-
-    port = pool_alloc(NIL, sizeof(struct port));
-
-    /* Assign the next next available port */
-    do {
-        inet_port = pl->next++;
-        sockfd = os_bind_inet_socket(inet_port, NIL);
-    }
-    while ((sockfd < 0) && (inet_port <= pl->last));
-
-    port->inet_port = inet_port;
-    port->sockfd = sockfd;
-    port->pid = 0;
-
-    list_unshift(pl->active, (struct list_item *) port, NIL);
-    return (port);
-}
-
 /* portlist_free_port_bypid() *******************************************
  *
  * Free a port based on process id of associated child process. (Actually
