@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/servers/prayer_login.c,v 1.6 2008/06/12 10:31:42 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/servers/prayer_login.c,v 1.15 2009/08/20 09:48:35 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -11,6 +11,26 @@
 #include "prayer_login.h"
 #include "prayer_server.h"
 
+char *read_file(struct pool *pool, char *filename)
+{
+    struct buffer *b = buffer_create(pool, 4096);
+    FILE *file;
+    int c;
+
+    if (!(file = fopen(filename, "r")))
+        return("");
+
+    while ((c = fgetc(file)) != EOF) {
+        if (c == '\n')
+            bputs(b, ""CRLF);
+        else
+            bputc(b, c);
+    }
+    fclose(file);
+
+    return (buffer_fetch(b, 0, buffer_size(b), NIL));
+}
+
 /* prayer_login_generate() ***********************************************
  *
  * Generate login screen
@@ -25,10 +45,9 @@ prayer_login_generate(struct prayer *prayer,
                       struct request *request, char *user, BOOL form)
 {
     struct config *config = prayer->config;
-    struct buffer *b = request->write_buffer;
-    FILE *file;
-    int c;
-    char *url_prefix = prayer_url_prefix(prayer, request->pool);
+    struct buffer *b    = request->write_buffer;
+    struct pool   *pool = request->pool;
+    struct template_vals *tvals = NIL;
     char *hostname;
 
     if (!prayer->use_ssl && config->ssl_required) {
@@ -36,150 +55,52 @@ prayer_login_generate(struct prayer *prayer,
         return;
     }
 
-    /* XXX Want some colour substitutions here? */
-    if (config->login_prefix_path &&
-        ((file = fopen(config->login_prefix_path, "r")) != NULL)) {
-        /* Config provides template for start of login page */
-        while ((c = fgetc(file)) != EOF) {
-            if (c == '\n')
-                bputs(b, "" CRLF);
-            else
-                bputc(b, c);
-        }
-        fclose(file);
-    } else {
-        /* Old behaviour */
-        if (config->login_banner)
-            html_common_start(config, b, config->login_banner);
-        else
-            html_common_start(config, b, "Webmail Service Login");
+    prayer_template_setup(prayer);  /* Adds $url_prefix automatically */
+    tvals = prayer->template_vals;
 
-        if (config->login_banner)
-            bprintf(b,
-                    "<h1 align=\"center\">%s</h1>" CRLF,
-                    config->login_banner);
-        else
-            bputs(b,
-                  "<h1 align=\"center\">Webmail Service Login</h1>" CRLF);
+    hostname = config->hostname_service ? config->hostname_service
+        : config->hostname;
+
+    template_vals_string(tvals, "$service_name", config->login_service_name);
+    template_vals_string(tvals, "$hostname", hostname);
+    template_vals_string(tvals, "$user", user);
+
+    if (config->raven_enable) {
+        template_vals_ulong(tvals, "$raven_enable", 1);
     }
 
-    /* Add plaintext warning if not SSL */
-    if ((prayer->use_ssl == NIL) && (config->ssl_default_port > 0)) {
-        bputs(b, "<table>" CRLF);
-        bputs(b, "<tr>" CRLF);
-        bputs(b, "<td><strong>Warning:</strong></td>");
-        bputs(b, "<td>This is an insecure HTTP session.</td></tr>" CRLF);
-        bputs(b, "<tr>" CRLF);
-        bputs(b, "<td>&nbsp;</td>" CRLF);
-        bputs(b, "<td>It is strongly recommended that you use ");
-        bputs(b, "SSL encryption if your browser supports it." CRLF);
-        bputs(b, "</td></tr>" CRLF);
-
-        bputs(b, "<tr>" CRLF);
-        bputs(b, "<td>&nbsp;</td>" CRLF);
-        bputs(b, "<td><strong>" CRLF);
-
-        hostname = config->hostname_service ? config->hostname_service
-                                            : config->hostname;
-        if (config->ssl_default_port != 443)
-            bprintf(b, "<a href=\"https://%s:%lu\">",
-                    hostname, config->ssl_default_port);
-        else
-            bprintf(b, "<a href=\"https://%s\">", hostname);
-        bputs(b, "Click Here</a> for an SSL enabled login session." CRLF);
-        bputs(b, "</strong></td></tr>" CRLF);
-
-        /* Link to insecure login if the form was not provided */
-        if (!form) {
-            bputs(b, "<tr>" CRLF);
-            bputs(b, "<td>&nbsp;</td>" CRLF);
-            bputs(b, "<td>" CRLF);
-            bputs(b, "For an insecure login session, ");
-            bprintf(b, "<a href=\"%s/login/\">click here</a>.", url_prefix);
-            bputs(b, "</td></tr>" CRLF);
-        }
-
-        bputs(b, "</table>" CRLF);
+    if (config->login_banner) {
+        template_vals_string(tvals, "$login_banner", config->login_banner);
     }
-
-    if (form) {
-        /* Actual login form */
-
-        bprintf(b, ("<form method=\"post\" accept-charset=\"UTF-8\""
-                    " enctype=\"multipart/form-data\""
-                    " action=\"%s%s\">"CRLF), url_prefix, request->url_path);
-
-        bputs(b, "<table cellpadding=\"5\">" CRLF);
-        bputs(b, "<tr>" CRLF);
-
-        bputs(b, "  <td>Username</td>" CRLF);
-
-        bputs(b, "  <td>");
-        bprintf(b, "<input name=\"username\" value=\"");
-        if (user)
-            html_quote_string(b, user);
-        bputs(b, "\" size=\"8\" maxlength=\"8\" />");
-        bputs(b, "</td>" CRLF);
-        bputs(b, "</tr>" CRLF);
-
-        bputs(b, "<tr>" CRLF);
-        bputs(b, "<td>Password</td>" CRLF);
-        bputs(b,
-                "<td><input type=\"password\" name=\"password\" size=\"16\" /></td>"
-                CRLF);
-        bputs(b, "</tr>" CRLF);
-
-        bputs(b, "<tr>" CRLF);
-        bputs(b, "  <td>&nbsp;</td>" CRLF);
-        bputs(b, "  <td>" CRLF);
-        bputs(b,
-                "    <input type=\"submit\" name=\"login\" value=\"Login\" />"
-                CRLF);
-        bputs(b, "  </td>" CRLF);
-        bputs(b, "</tr>" CRLF);
-        bputs(b, "</table>" CRLF);
-
-        bputs(b, "</form>" CRLF);
-    }
-
     if (config->motd_path) {
-        /* MOTD */
-        if ((file = fopen(config->motd_path, "r")) != NULL) {
-            while ((c = fgetc(file)) != EOF) {
-                if (c == '\n')
-                    bputs(b, "" CRLF);
-                else
-                    bputc(b, c);
-            }
-            fclose(file);
-        }
+        template_vals_string(tvals, "$motd",
+                             read_file(pool, config->motd_path));
+    }
+    if (config->login_insert1_path) {
+        template_vals_string(tvals, "$login_insert1",
+                             read_file(pool, config->login_insert1_path));
+    }
+    if (config->login_insert2_path) {
+        template_vals_string(tvals, "$login_insert2",
+                             read_file(pool, config->login_insert2_path));
     }
 
-    if (config->login_suffix_path &&
-        ((file = fopen(config->login_suffix_path, "r")) != NULL)) {
-        /* Config provides template for end of login page */
-
-        while ((c = fgetc(file)) != EOF) {
-            if (c == '\n')
-                bputs(b, "" CRLF);
-            else
-                bputc(b, c);
-        }
-        fclose(file);
-    } else {
-        /* Old behaviour */
-        html_common_end(b);
+    if ((prayer->use_ssl == NIL) && (config->ssl_default_port > 0)) {
+        template_vals_ulong(tvals, "$ssl_available", 1);
+        template_vals_ulong(tvals, "$ssl_port", config->ssl_default_port);
+    
     }
 
-    /* Send out the response */
+    template_expand(config->login_template, tvals, b);
     response_html(request, 200);
 }
 
+/* ====================================================================== */
 /* ====================================================================== */
 
-/* prayer_login_process_request() ****************************************
+/* prayer_login_attempt() ************************************************
  *
- * Process login request (static support function)
+ * Attempt login to prayer-session backend
  *   prayer: Global state
  * username: Username to send to IMAP server
  * password: Password to send to IMAP server
@@ -189,10 +110,10 @@ prayer_login_generate(struct prayer *prayer,
  * Connection/protocol error if either *statusp and *valuep NIL on return
  ************************************************************************/
 
-static void
-prayer_login_process_request(struct prayer *prayer,
-                             char *username, char *password,
-                             char **statusp, char **valuep)
+static BOOL
+prayer_login_attempt(struct prayer *prayer,
+                     char *username, char *password,
+                     char **statusp, char **valuep)
 {
     struct config *config = prayer->config;
     struct request *request = prayer->request;
@@ -203,7 +124,7 @@ prayer_login_process_request(struct prayer *prayer,
     int sockfd;
     struct buffer *b = buffer_create(pool, 0L);
     int c;
-    char *line, *status, *value;
+    char *line, *status = "NO", *value = "";
     char *ua_options;
 
     *statusp = NIL;
@@ -212,24 +133,24 @@ prayer_login_process_request(struct prayer *prayer,
     if (!(username && username[0])) {
         *statusp = "NO";
         *valuep = "No username supplied";
-        return;
+        return(NIL);
     }
 
     if (!(password && password[0])) {
         *statusp = "NO";
         *valuep = "No password supplied";
-        return;
+        return(NIL);
     }
 
     socketname = pool_printf(pool, "%s/%s",
                              config->socket_dir, config->init_socket_name);
 
     if ((sockfd = os_connect_unix_socket(socketname)) < 0)
-        return;
+        return(NIL);
 
     if ((iostream = iostream_create(pool, sockfd, 0)) == NIL) {
         log_misc("[process_login_request()] iostream_create() failed");
-        return;
+        return(NIL);
     }
 
     iostream_set_timeout(iostream, config->session_timeout);
@@ -250,7 +171,7 @@ prayer_login_process_request(struct prayer *prayer,
 
     if (c == EOF) {
         log_misc("[process_login_request()] iogetc() got end of file");
-        return;
+        return(NIL);
     }
 
     line = buffer_fetch(b, 0, buffer_size(b), NIL);
@@ -258,13 +179,165 @@ prayer_login_process_request(struct prayer *prayer,
     status = string_get_token(&line);
     value = string_next_token(&line);
 
-    if (!(status && value))
+    if (!(status && value)) {
         log_misc("[process_login_request()] Invalid response from server");
+        return(NIL);
+    }
 
     *statusp = status;
     *valuep = value;
+    return(T);
+}
+
+/* Couple of support functions shared between prayer_login_process()
+ * and prayer_login_raven()
+ */
+
+static void
+prayer_login_connect_error(struct prayer *prayer, char *username)
+{
+    struct request *request = prayer->request;
+    struct buffer  *b       = request->write_buffer;
+    struct template_vals *tvals = NIL;
+
+    prayer_template_setup(prayer);  /* Adds $url_prefix automatically */
+
+    tvals = prayer->template_vals;
+    template_vals_string(tvals, "$user", username);
+    template_expand("frontend_session", tvals, b);
+    response_html(request, 200);
+}
+
+static void
+prayer_login_error(struct prayer *prayer, char *username, char *value)
+{
+    struct request *request = prayer->request;
+    struct buffer *b = request->write_buffer;
+    struct template_vals *tvals = NIL;
+
+    prayer_template_setup(prayer);  /* Adds $url_prefix automatically */
+
+    tvals = prayer->template_vals;
+    template_vals_string(tvals, "$user", username);
+    template_vals_string(tvals, "$value", value);
+
+    template_expand("frontend_login_error", tvals, b);
+    response_html(request, 200);
+}
+
+/* ====================================================================== */
+
+/* prayer_login_raven() **************************************************
+ *
+ * Process Raven login request
+ *    prayer: Global state
+ *  username: Default login name.
+ ************************************************************************/
+
+#ifdef RAVEN_ENABLE
+void
+prayer_login_raven(struct prayer *prayer)
+{
+    struct request *request = prayer->request;
+    struct config  *config  = request->config;
+    struct pool    *pool    = request->pool;
+    char *username = NIL;
+    char *password = NIL;
+    char *status = "NO";
+    char *value = "";
+    char *url_prefix = prayer_url_prefix(prayer, request->pool);
+    char *raven_prefix = pool_strcat(request->pool, url_prefix, "/raven");
+    char *wls_token;
+    struct raven_wls_response *wls;
+
+    if (request->argc != 1) {
+        response_error(request, 404);
+        return;
+    }
+
+    if (!(config->raven_enable &&
+          config->raven_key_path && config->raven_key_path[0])) {
+        response_error(request, 404);
+        return;
+    }
+
+    request_decode_form(request);
+    wls_token = assoc_lookup(request->form, "WLS-Response");
+
+    if (!(wls_token && wls_token[0])) {
+        char *callback_url = pool_strcat(pool, url_prefix, "/raven");
+        char *service_name = "Prayer Webmail Service";
+        char *login_url;
+
+        if (config->login_service_name)
+            service_name = pool_printf(pool, "%s Webmail Service",
+                                       config->login_service_name);
+        login_url = pool_printf
+            (pool,
+             "%s?ver=1&url=%s&date=%s&desc=%s",
+             "https://raven.cam.ac.uk/auth/authenticate.html",
+             string_url_encode(pool, callback_url),
+             string_url_encode(pool, raven_wls_response_now()),
+             string_url_encode(pool, service_name));
+
+        response_redirect(request, login_url);
+        return;
+    }
+
+    wls = raven_wls_response_parse(wls_token, config->raven_key_path, &value);
+    
+    if (!wls) {
+        /* error provided by parse routine */
+    } else if (strcmp(wls->status, "200") != 0) {
+        if (wls->msg && wls->msg[0]) {
+            value = pool_printf(pool, "%s: %s", wls->status, wls->msg);
+                                
+        } else {
+            value = pool_printf(pool, "%s: %s", wls->status,
+                                raven_wls_response_status_message(wls));
+        }
+    } else if (strcmp(wls->url, raven_prefix) != 0) {
+        value  = "Authentication response for wrong system";
+    } else if (!raven_wls_response_check_timestamp
+               (wls, RAVEN_WLS_TICKET_MAXSKEW, RAVEN_WLS_TICKET_TIMEOUT)) {
+        value = "Authentication response timed out";
+    } else {
+        username = pool_strdup(pool, wls->principal);
+        password = wls_token;
+    }
+
+    if (wls) {
+        request->log_entry = pool_printf
+            (pool, "GET /raven?WLS-Response=%s!...", wls->lhs); 
+        raven_wls_response_free(wls);
+    }
+
+    if (username && password &&
+        !prayer_login_attempt(prayer, username, password,
+                              &status, &value)) {
+        if (status && value) {
+            prayer_login_error(prayer, username, value);
+        } else {
+            prayer_login_connect_error(prayer, username);
+        }
+        return;
+    }
+
+    if (status && !strcmp(status, "OK"))
+        response_redirect(request, value);
+    else /* Should never happen... */
+        prayer_login_error(prayer, username, value);
+}
+#else
+void
+prayer_login_raven(struct prayer *prayer)
+{
+    struct request *request = prayer->request;
+
+    response_error(request, 404);
     return;
 }
+#endif
 
 /* ====================================================================== */
 
@@ -279,13 +352,11 @@ static void
 prayer_login_process(struct prayer *prayer, struct request *request)
 {
     struct config *config = request->config;
-    struct user_agent *user_agent = request->user_agent;
     struct buffer *b = request->write_buffer;
     char *username;
     char *password;
-    char *status;
+    char *status = "NO";
     char *value;
-    char *url_prefix = prayer_url_prefix(prayer, request->pool);
 
     /* Decode information from post request */
     request_decode_form(request);
@@ -293,6 +364,9 @@ prayer_login_process(struct prayer *prayer, struct request *request)
     username = assoc_lookup(request->form, "username");
     password = assoc_lookup(request->form, "password");
 
+    if (username)
+        username = string_trim_whitespace(username);
+
     if ((config->referer_log_invalid || config->referer_block_invalid) &&
         !request_test_referer(request, config->hostname_service) &&
         !request_test_referer(request, config->hostname)) {
@@ -302,67 +376,33 @@ prayer_login_process(struct prayer *prayer, struct request *request)
                      assoc_lookup(request->hdrs, "referer"));
 
         if (config->referer_block_invalid) {
-            html_common_start(config, b, "Security Alert");
-            bputs(b, "<h2>Security Alert</h2>"CRLF);
-
-            bprintf(b, ("<p>Login request did not come from "
-                        "<a href = \"%s\">%s<a/></p>. "CRLF),
-                    url_prefix, url_prefix);
-
-            html_common_end(b);
+            prayer_template_setup(prayer);  /* Adds $url_prefix automatically */
+            template_expand("frontend_security", prayer->template_vals, b);
             response_html(request, 200);
             return;
         }
     }
 
-    prayer_login_process_request(prayer, username, password, &status,
-                                 &value);
-
-    if (!(status && value)) {
-        html_common_start(config, b, "System Error");
-        bprintf(b,
-                "<h1>Couldn't connect to Webmail session server</h1>"
-                CRLF);
-        if (username) {
-            bprintf(b, "<a href=\"%s/login/", url_prefix);
-            html_quote_string(b, username);
-            bprintf(b, "\">Try again</a> later" CRLF);
-        } else
-            bprintf(b, "<a href=\"%s\">Try again</a> later" CRLF,
-                    url_prefix);
-
-        html_common_end(b);
-        response_html(request, 200);
+    if ((config->raven_enable) && (password) && (strlen(password) > 256)) {
+        prayer_login_error(prayer, username, "Password too long");
         return;
     }
 
-    if (!strcmp(status, "OK")) {
+    if (!prayer_login_attempt(prayer, username, password, &status, &value)) {
+        if (status && value) {
+            prayer_login_error(prayer, username, value);
+        } else {
+            prayer_login_connect_error(prayer, username);
+        }
+        return;
+    }
+    if (status && !strcmp(status, "OK"))
         response_redirect(request, value);
-        return;
-    }
-
-    html_common_start(config, b, "Login Failed");
-    bprintf(b, "<h1>Login failed</h1>" CRLF);
-
-    bputs(b, "<hr />");
-
-    bputs(b, "<b>Status:</b> ");
-    html_common_quote_string(b, value);
-    bputs(b, "" CRLF);
-    bputs(b, "<hr />");
-
-    if (username) {
-        bprintf(b, "Please <a href=\"%s/login/", url_prefix);
-        html_quote_string(b, username);
-        bprintf(b, "\">try again</a>" CRLF);
-    } else
-        bprintf(b, "Please <a href=\"%s\">try again</a>" CRLF,
-                url_prefix);
-
-    html_common_end(b);
-    response_html(request, 200);
+    else /* Should never happen... */
+        prayer_login_error(prayer, username, value);
 }
 
+/* ====================================================================== */
 /* ====================================================================== */
 
 /* prayer_login() ********************************************************
@@ -422,3 +462,4 @@ void prayer_login_preamble(struct prayer *prayer)
         prayer_login(prayer, NIL);
     }
 }
+
