@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/servers/prayer_server.c,v 1.10 2009/04/03 13:19:02 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/servers/prayer_server.c,v 1.12 2010/07/02 14:42:55 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -79,16 +79,23 @@ static void generate_connect_error_page(struct prayer *prayer)
     struct request *request = prayer->request;
     struct buffer *b = request->write_buffer;
     struct template_vals *tvals = prayer->template_vals;
+    char *username = "";
+    char *s;
 
     prayer_template_setup(prayer);
     tvals = prayer->template_vals;
 
-    if (request->argc >= 2)
-        template_vals_string(tvals, "user", request->argv[1]);
+    if (request->argc >= 1) {
+        username = pool_strdup(request->pool, request->argv[1]);
+        if ((s=strchr(username, ':')))
+            *s = '\0';
+
+        template_vals_string(tvals, "user", username);
+    }
 
     if ((request->argc >= 5) && (!strcmp(request->argv[4], "compose")) &&
         (request->method == POST)) {
-        prayer_compose_dump(prayer, request, request->argv[1]);
+        prayer_compose_dump(prayer, request, username);
     } else {
         template_expand("frontend_timeout", tvals, b);
     }
@@ -130,7 +137,7 @@ static BOOL prayer_process_session_request(struct prayer *prayer)
         return (NIL);
     }
 
-    /* Decode username argument */
+    /* Decode username+pid argument */
     string_url_decode(request->argv[1]);
 
     /* Check decoded string for sneakiness */
@@ -146,13 +153,6 @@ static BOOL prayer_process_session_request(struct prayer *prayer)
         char *s = assoc_lookup(request->hdrs, "cookie");
         char *t;
         char *u;
-        char *key;
-
-        if (config->http_cookie_use_port)
-            key = pool_printf(request->pool, "%s:%lu",
-                              request->argv[1], prayer->port);
-        else
-            key = request->argv[1];
 
         /* Need cookie parsing library? */
         while (s && *s && (t = strchr(s, '='))) {
@@ -160,7 +160,7 @@ static BOOL prayer_process_session_request(struct prayer *prayer)
             if ((u = strchr(t, ';')))
                 *u++ = '\0';
 
-            if (!strcmp(string_trim_whitespace(s), key)) {
+            if (!strcmp(string_trim_whitespace(s), request->argv[1])) {
                 request->argv[2] = string_trim_whitespace(t);
                 break;
             }
@@ -191,6 +191,7 @@ static BOOL prayer_process_session_request(struct prayer *prayer)
         socketname = pool_printf(request->pool, "%s/%c/%s:%s",
                                  config->socket_dir, request->argv[2][0],
                                  request->argv[1], request->argv[2]);
+
         fd = os_connect_unix_socket(socketname);
 
         /* Backwards compatibility */
