@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/account_sieve.c,v 1.6 2010/07/05 16:04:24 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/account_sieve.c,v 1.7 2011/09/09 16:34:36 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -736,7 +736,7 @@ account_sieve_mail_update(struct account *account, struct pool *pool)
 
     if (auto_text && auto_text[0]) {
         if (!sieve_upload(sieve, session, "auto", auto_text)) {
-            account_message(account, "failed up upload auto file: %s",
+            account_message(account, "failed to upload auto file: %s",
                             sieve_fetch_message(sieve));
             return(NIL);
         }
@@ -745,7 +745,7 @@ account_sieve_mail_update(struct account *account, struct pool *pool)
     } else {
         if (account->sieve_have_auto &&
             !sieve_delete(sieve, session, "auto")) {
-            account_message(account, "failed up delete auto file: %s",
+            account_message(account, "failed to delete auto file: %s",
                             sieve_fetch_message(sieve));
             return(NIL);
         }
@@ -760,13 +760,13 @@ account_sieve_mail_update(struct account *account, struct pool *pool)
         sieve_current_record(sieve, sieve_text);
 
         if (!sieve_upload(sieve, session, "sieve", sieve_text)) {
-            account_message(account, "failed up upload sieve file: %s",
+            account_message(account, "failed to upload sieve file: %s",
                             sieve_fetch_message(sieve));
             return(NIL);
         }
 
         if (!sieve_activate(sieve, session, "sieve")) {
-            account_message(account, "failed up activate sieve file: %s",
+            account_message(account, "failed to activate sieve file: %s",
                             sieve_fetch_message(sieve));
             return(NIL);
         }
@@ -775,8 +775,11 @@ account_sieve_mail_update(struct account *account, struct pool *pool)
     } else {
         sieve_current_record(sieve, NIL);
 
-        if (sieve_live(sieve) && !sieve_delete(sieve, session, "sieve")) {
-            account_message(account, "failed up delete sieve file: %s",
+        /* Need to deactivate sieve file before deleting with Cyrus 2.4 */
+        if (sieve_live(sieve) && 
+            (!sieve_activate(sieve, session, "") ||
+             !sieve_delete(sieve, session, "sieve"))) {
+            account_message(account, "failed to delete sieve file: %s",
                             sieve_fetch_message(sieve));
             return(NIL);
         }
