@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/draft.c,v 1.20 2010/07/02 16:15:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/draft.c,v 1.25 2011/06/22 15:34:36 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -104,34 +104,93 @@ format_references(struct pool *pool, char *s)
     return(buffer_fetch(b, 0, buffer_size(b), NIL));
 }
 
-unsigned long
-draft_rfc1522_encode(struct buffer *b, char *s)
+/* Convert UTF-8 string to RFC1522 encoding (but only if required).  Label
+ * as ISO-8851 if only Latin 1 characters actually in use.  Uses temporary
+ * scratch buffer (same size as PINE). Final result always pool_strdup()ed
+ * from the pool that we are given. 
+ */
+static char *
+draft_rfc1522_encode(struct pool *pool, char *s, BOOL *encodedp)
 {
-    char *tmp;
-    BOOL is_8859_1;
-    unsigned long len;
+    char tmp[20*1024];  /* PINE uses scratch buffer this size */
+    BOOL is_8859_1 = utf8_is_8859_1(s);
+    BOOL encoded = NIL;
 
-    if (!(s && s[0]))
-        return(0);
-
-    if ((is_8859_1 = utf8_is_8859_1(s))) {
-        s = pool_strdup(b->pool, s);
+    if (is_8859_1) {
+        s = pool_strdup(pool, s);
         utf8_to_8859_1(s);
     }
-
-    /* Nasty fudge for safe upper bound */
-    len = (4 * strlen(s)) + 1024;
-    tmp = pool_alloc(NIL, len);
-
-    s = (char *) rfc1522_encode(tmp, len, (unsigned char *)s,
+    s = (char *) rfc1522_encode(tmp, sizeof(tmp),
+                                (unsigned char *)s,
                                 (is_8859_1) ? "ISO-8859-1" : "UTF-8");
-    bputs(b, s);
-    len = strlen(s);
-    free(tmp);
+    if (s == tmp) {
+        encoded = T;
+        s = pool_strdup(pool, s);
+    }
+    if (encodedp)
+        *encodedp = encoded;
+    
+    return(s);
+}
+
+/* ====================================================================== */
+
+/* draft_print_subject() is modified version of draft_rfc1522_encode()
+ * which wraps subject line when rfc1522 encoder is NOOP.
+ */
+
+static int
+mywordlen(char *s)
+{
+    int len = 0;
+
+    while (*s && !string_isspace(*s)) {
+        s++;
+        len++;
+    }
 
     return(len);
 }
 
+static void
+draft_print_subject_fold(struct buffer *b, char *s)
+{
+    int col = strlen("Subject: ")+1;
+
+    while (*s) {
+        if (s[1] && string_isspace(s[0]) && !string_isspace(s[1])) {
+            /* Linebreak on last LWS character before new word */
+            if ((col + mywordlen(s)) >= 76) {
+                bputs(b, CRLF" ");
+                col=2;
+                s++;
+            }
+        }
+        bputc(b, *s++);
+        col++;
+    }
+}
+
+static void
+draft_print_subject(struct buffer *b, struct pool *pool, char *s)
+{
+    BOOL encoded = NIL;
+
+    s = draft_rfc1522_encode(pool, s, &encoded);
+
+    bputs(b, "Subject: ");
+
+    if (encoded) {
+        /* rfc1522_encode() kicked in, with automatic line wrap */
+        bputs(b, s);
+    } else {
+        /* Need to wrap original input string */
+        draft_print_subject_fold(b, s); 
+    }
+
+    bputs(b, CRLF);
+}
+
 /* ====================================================================== */
 
 /* draft_create() ********************************************************
@@ -894,73 +953,50 @@ char *draft_make_recipients(struct draft *draft,
 
 /* ====================================================================== */
 
-/* draft_make_single_address() *******************************************
+/* draft_make_addr() ****************************************************
  *
  * Convert single address item into RFC822 format recipient, including
  * nasty charset munging
  *   session:
- *        mb: Target buffer for message
+ *       str: Scratch str.
  *  personal: Personal component of recipient
  *   mailbox: Mailbox  component of recipient
  *      host: Host     component of recipient
  *
- * Returns: length of the item that we just printed.
+ * Returns: Combined string
  ************************************************************************/
 
-static unsigned long
-draft_make_single_address(struct session *session,
-                          struct buffer *mb,
-                          char *personal, char *mailbox, char *host)
+static char *
+draft_make_addr(struct str *str, struct pool *pool,
+                char *personal, char *mailbox, char *host)
 {
-    struct request *request = session->request;
-    struct pool *pool = request->pool;
-    char *s;
-    unsigned long len = 0;
+    str_rewind(str, 0);
 
     if (personal && personal[0]) {
-        unsigned long count = 0;
-
-        for (s = personal; *s; s++) {
-            if ((*s) & 0x80)
-                count++;
-        }
-
-        if (count > 0) {
-            len = draft_rfc1522_encode(mb, personal);
+        if (string_has8bit(personal)) {
+            str_puts(str, draft_rfc1522_encode(pool, personal, NIL));
         } else if (string_atom_has_special(personal)) {
-            personal =
-                pool_printf(pool, "\"%s\"",
-                            string_atom_quote(pool, personal));
-            
-            bputs(mb, personal);
-            len = strlen(personal);
+            str_printf(str, "\"%s\"", string_atom_quote(pool, personal));
         } else {
-            bputs(mb, personal);
-            len = strlen(personal);
+            str_puts(str, personal);
         }
 
         if (mailbox && mailbox[0] && host && host[0]) {
-            bprintf(mb, " <%s@%s>", mailbox, host);
-            len += 4 + strlen(mailbox) + strlen(host);
+            str_printf(str, " <%s@%s>", mailbox, host);
         } else if (mailbox && mailbox[0]) {
-            bprintf(mb, " <%s>", mailbox);
-            len += 3 + strlen(mailbox);
+            str_printf(str, " <%s>", mailbox);
         } else if (host && host[0]) {
-            bprintf(mb, " <%s>", host);
-            len += 3 + strlen(host);
+            str_printf(str, " <%s>", host);
         }
     } else if (mailbox && mailbox[0] && host && host[0]) {
-        bprintf(mb, "%s@%s", mailbox, host);
-        len += 1 + strlen(mailbox) + strlen(host);
+        str_printf(str, "%s@%s", mailbox, host);
     } else if (mailbox && mailbox[0]) {
-        bputs(mb, mailbox);
-        len += strlen(mailbox);
+        str_puts(str, mailbox);
     } else if (host && host[0]) {
-        bputs(mb, mailbox);
-        len += strlen(host);
+        str_puts(str, mailbox);
     }
 
-    return (len);
+    return (str_fetch(str));
 }
 
 /* ====================================================================== */
@@ -979,7 +1015,12 @@ draft_make_address(struct session *session,
                    struct buffer *mb, char *hdr, char *text)
 {
     ADDRESS *a, *addr = NIL;
-    unsigned long offset = 0;
+    struct request *request = session->request;
+    struct pool    *pool    = request->pool;
+    struct str     *tmpstr  = str_create(request->pool, 0);
+    int offset = 0;
+    int count = 0;
+    int i;
 
     /* Quietly ignore empty fields */
     if (!(text && text[0]))
@@ -991,23 +1032,32 @@ draft_make_address(struct session *session,
     }
 
     bprintf(mb, "%s: ", hdr);
+    offset = strlen(hdr) + strlen(": ");
 
     for (a = addr; a; a = a->next) {
-        /* XXX Not quite right: Need length of item first */
-        offset += draft_make_single_address(session, mb,
-                                            a->personal, a->mailbox,
-                                            a->host);
-        if (a->next) {
-            if (offset >= 76) {
-                bputs(mb, "," CRLF "   ");
-                offset = 3;
+        char *s = draft_make_addr(tmpstr, pool, 
+                                  a->personal, a->mailbox, a->host);
+        int len = strlen(s);
+
+        if (count > 0) {
+            /* ',' separator, with potential line fold */
+            if ((offset+len+2) >= 78) {
+                bputs(mb, "," CRLF);
+
+                //offset = strlen(hdr) + strlen(": ");
+                offset = 4;
+                for (i = 0; i < offset; i++)
+                    bputc(mb, ' ');
             } else {
                 bputs(mb, ", ");
                 offset += 2;
             }
         }
-    }
 
+        bputs(mb, s);
+        offset += len;
+        count++;
+    }
     bputs(mb, "" CRLF);
     mail_free_address(&addr);
     return (T);
@@ -1247,7 +1297,9 @@ static void draft_make_multipart(struct draft *draft, struct buffer *b)
                 type = "application/octet-stream";
 
             if (name && name[0]) {
-                if (string_has8bit(name) || strchr(name, '"')) {
+                if (string_has8bit(name) ||
+                    strchr(name, '"') ||
+                    strlen(name) > 78) {
                     /* Need RFC 2231 encoding */
 
                     if (utf8_is_8859_1(name)) {
@@ -1269,7 +1321,12 @@ static void draft_make_multipart(struct draft *draft, struct buffer *b)
                             name);
                     bprintf(b, "Content-Description: "CRLF);
 
-                } else if (strchr(name, ' ') || strchr(name, '\t')) {
+                } else if (strpbrk(name, " \t()<>@,;:\\/[]?=")) {
+                    /* RFC 2183 (Section 2) lists characters which must be
+                     * quoted. '"' is handled above: could be quoted as \",
+                     * (rfc822 "quoted-string"), but RFC 2231 encoding feels
+                     * safer to me.
+                     */
                     bprintf(b, "Content-Type: %s; name=\"%s\"" CRLF,
                             type, name);
                     bprintf(b,
@@ -1438,6 +1495,7 @@ char *draft_make_msg(struct draft *draft, BOOL postpone,
     char *default_domain = prefs->default_domain;
     struct pool *pool = session->request->pool;
     struct buffer *mb = buffer_create(pool, 4096);
+    struct str *str = str_create(pool, 0);
     char *s, *value;
     char *from_address, *from_personal = NIL;
     BOOL use_sender = NIL;
@@ -1489,11 +1547,8 @@ char *draft_make_msg(struct draft *draft, BOOL postpone,
     }
 
     bprintf(mb, "Date: %s" CRLF, date);
-
-    bputs(mb, "From: ");
-    draft_make_single_address(session, mb, from_personal, from_address,
-                              NIL);
-    bputs(mb, "" CRLF);
+    bprintf(mb, "From: %s" CRLF,
+            draft_make_addr(str, pool, from_personal, from_address, NIL));
 
     if (use_sender) {
         if (strchr(session->username, '@')) {
@@ -1512,11 +1567,8 @@ char *draft_make_msg(struct draft *draft, BOOL postpone,
     if ((s = draft->reply_to) && s[0])
         draft_make_address(session, mb, "Reply-To", s);
 
-    if ((s = draft->subject) && s[0]) {
-        bputs(mb, "Subject: ");
-        draft_rfc1522_encode(mb, s);
-        bprintf(mb, CRLF);
-    }
+    if ((s = draft->subject) && s[0])
+        draft_print_subject(mb, pool, s);
 
     if (draft->fcc && draft->fcc[0] && !string_filename_valid(draft->fcc)) {
         session_message(session, "Invalid Fcc name");
