@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/filter.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/filter.c,v 1.4 2011/06/15 14:43:47 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -336,6 +336,18 @@ filter_sieve_print_target(struct filter *filter, struct buffer *b)
         bputs(b, "   stop;"CRLF);
 }
 
+static void
+filter_sieve_print_discard(struct filter *filter, struct buffer *b)
+{
+    bputs(b, "\"");
+    filter_sieve_print_quote(b, filter->local_part);
+    bputc(b, '@');
+    filter_sieve_print_quote(b, filter->domain);
+    bputs(b, "\" {"CRLF);
+    bputs(b, "   discard; stop;"CRLF);
+    bputs(b, "}"CRLF""CRLF);
+}
+
 /* filter_sieve_print() **************************************************
  *
  * Convert filter into Sieve format string
@@ -395,16 +407,17 @@ filter_sieve_print(struct filter *filter, struct buffer *b)
             return(NIL);
 
         if (filter_address_has_wildcard(filter))
-            bputs(b, "if envelope :matches \"from\" \"");
+            bputs(b, "if envelope :matches \"from\" ");
         else
-            bputs(b, "if envelope :is \"from\" \"");
+            bputs(b, "if envelope :is \"from\" ");
+        filter_sieve_print_discard(filter, b);
+
+        if (filter_address_has_wildcard(filter))
+            bputs(b, "if address :all :matches [\"from\", \"sender\"] ");
+        else
+            bputs(b, "if address :all :is [\"from\", \"sender\"] ");
+        filter_sieve_print_discard(filter, b);
 
-        filter_sieve_print_quote(b, filter->local_part);
-        bputc(b, '@');
-        filter_sieve_print_quote(b, filter->domain);
-        bputs(b, "\" {"CRLF);
-        bputs(b, "   discard; stop;"CRLF);
-        bputs(b, "}"CRLF""CRLF);
         break;
     default:
         return(NIL);
