@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/folderlist.c,v 1.2 2008/05/19 15:55:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/folderlist.c,v 1.7 2009/09/01 10:28:12 dpc22 Exp $ */
 
 /* folderlist caches the mailboxlist used on the server */
 
@@ -19,6 +19,7 @@ folderitem_create(struct pool *pool, char *name)
     result->noinferiors = T;
     result->haschildren = T;   /* Assume true until server tells us otherwise */
     result->expanded    = NIL;
+    result->size        = 0L;
 
     return (result);
 }
@@ -32,6 +33,7 @@ folderitem_create(struct pool *pool, char *name)
 static struct {
     struct pool *pool;
     BOOL toplevel;
+    char hiersep;
     struct folderitem *inbox;
     struct folderitem *first;
     struct folderitem *last;
@@ -47,6 +49,7 @@ folderlist_callback(MAILSTREAM * stream,
     struct pool       *pool = callback.pool;
     struct folderitem *fi;
     struct folderitem *last, *current;
+    size_t namelen;
 
     callback.count++;
     if (callback.prefix && callback.prefix[0]) {
@@ -55,6 +58,23 @@ folderlist_callback(MAILSTREAM * stream,
 
         name += callback.prefix_length;
     }
+
+    /* UW and Dovecot return placeholder for directory when running
+     *   . list "mail/" %
+     *   * LIST (\NoSelect \HasChildren) "/" mail/
+     *   * LIST (\NoInferiors \UnMarked) "/" mail/gg
+     *
+     * Cyrus does not.
+     *
+     * IMAP specification is ambiguous: '%' matches zero or more
+     * characters, but example in RFC 3501 matches Cyrus result.
+     *
+     * Need to skip the placeholder line if present.
+     */
+    namelen = strlen(name);
+    if ((namelen > 0) && name[namelen-1] == callback.hiersep)
+	return;
+
     if (*name == '\0')
         return;                 /* Empty name */
 
@@ -84,7 +104,7 @@ folderlist_callback(MAILSTREAM * stream,
         return;
     }
 
-    if (strcasecmp(callback.first->name, name) > 0) { 
+    if (strcmp(callback.first->name, name) > 0) { 
         /* Insert at head of list */
         fi->next       = callback.first;
         callback.first = fi;
@@ -131,6 +151,7 @@ folderlist_expand(struct session *session, struct folderitem *fi)
     callback.last  = NIL;
     callback.count = 0;
     callback.toplevel = NIL;
+    callback.hiersep = fl->hiersep;
     callback.inbox    = NIL;
 
     mm_register_list_callback(folderlist_callback);
@@ -170,6 +191,7 @@ folderlist_toplevel(struct session *session)
     callback.last  = NIL;
     callback.count = 0;
     callback.toplevel = T;
+    callback.hiersep = fl->hiersep;
     callback.inbox    = NIL;
 
     mm_register_list_callback(folderlist_callback);
@@ -202,13 +224,12 @@ folderlist_toplevel(struct session *session)
 /* Public Interface */
 
 struct folderlist *
-folderlist_create(char *maildir, char *hiersep)
+folderlist_create(char *hiersep)
 {
     struct pool       *pool   = pool_create(FOLDERLIST_PREFERRED_POOL_SIZE);
     struct folderlist *result = pool_alloc(pool, sizeof(struct folderlist));
 
     result->pool  = pool;
-    result->maildir = (maildir) ? pool_strdup(pool, maildir) : "";
     result->tree  = NIL;
     result->need_update = T;
     result->hiersep = (hiersep && hiersep[0]) ? hiersep[0] : '/';
@@ -249,13 +270,11 @@ struct folderlist *folderlist_fetch(struct session *session)
 {
     struct folderlist *old = session->folderlist;
     struct folderlist *new;
-    struct prefs *prefs = session->options->prefs;
 
     if (old && !old->need_update)
         return(old);
 
-    session->folderlist = new
-        = folderlist_create(prefs->maildir, session->hiersep);
+    session->folderlist = new = folderlist_create(session->hiersep);
 
     folderlist_toplevel(session);
 
@@ -325,6 +344,72 @@ folderlist_expand_parents(struct folderlist *fl, char *name)
 
 /* ====================================================================== */
 
+static BOOL
+folderlist_update_sizes_single(struct folderitem *fi,
+                               MAILSTREAM *stream,
+                               struct session *session)
+{
+    unsigned long msgno;
+    MESSAGECACHE *elt;
+
+    if (!ml_fetch_fast(session, stream, "1:*", 0))
+        return(NIL);
+
+    fi->size = 0L;
+    for (msgno = 1; msgno <= stream->nmsgs; msgno++) {
+        if (!(elt = ml_elt(session, stream, msgno)))
+            return (NIL);
+        fi->size += elt->rfc822_size;
+    }
+    return(T);
+}
+
+static BOOL
+folderlist_update_sizes_work(struct folderitem *fi,
+                             MAILSTREAM **streamp,
+                             struct session *session)
+{
+    struct pool *pool = session->request->pool;
+
+    while (fi) {
+        if (!fi->noselect) {
+            *streamp = ml_open(session, *streamp,
+                               session_mailbox(session, pool, fi->name),
+                               OP_READONLY);
+
+            if (!(*streamp))
+                return(NIL);
+            folderlist_update_sizes_single(fi, *streamp, session);
+        }
+        if (fi->child && fi->expanded) {
+            folderlist_update_sizes_work(fi->child, streamp, session);
+        }
+        fi = fi->next;
+    }
+    return(T);
+}
+
+BOOL
+folderlist_update_sizes(struct folderlist *fl,
+                        struct session *session)
+{
+    BOOL rc;
+    MAILSTREAM *tmp = ml_open(session, NIL,
+                              session_mailbox_prefs(session, NIL),
+                              OP_HALFOPEN);
+    if (!tmp)
+        return(NIL);
+
+    rc = folderlist_update_sizes_work(fl->tree, &tmp, session);
+
+    if (tmp)
+        ml_close(session, tmp);
+
+    return(rc);
+}
+
+/* ====================================================================== */
+
 void folderlist_invalidate(struct folderlist *fl)
 {
     fl->need_update = T;
@@ -342,7 +427,7 @@ folderlist_add(struct folderlist *fl, char *name,
     struct folderitem *last, *current;
 
     /* Don't try to optimise difficult cases */
-    if ((fl->maildir && fl->maildir[0]) || strchr(name, fl->hiersep)) {
+    if (strchr(name, fl->hiersep)) {
         folderlist_expand_parents(fl, name);
         folderlist_invalidate(fl);
         return;
@@ -380,7 +465,7 @@ folderlist_delete(struct folderlist *fl, char *name)
     struct folderitem *last, *current;
 
     /* Don't try to optimise difficult cases */
-    if ((fl->maildir && fl->maildir[0]) || strchr(name, fl->hiersep)) {
+    if (strchr(name, fl->hiersep)) {
         folderlist_invalidate(fl);
         return;
     }
@@ -521,6 +606,22 @@ folderlist_showfolders_select(struct folderlist *fl, BOOL suppress_dotfiles,
 
 /* ====================================================================== */
 
+static char *
+mbytes(unsigned long bytes)
+{
+    static char buf[64];
+    unsigned long kbytes   = bytes / 1024;
+    unsigned long whole    = kbytes / (1024);
+    unsigned long fraction = ((kbytes % 1024) * 100) / 1024;
+
+    if (fraction > 9)
+        sprintf(buf, "%lu.%lu", whole, fraction);
+    else
+        sprintf(buf, "%lu.0%lu", whole, fraction);
+
+    return(buf);
+}
+
 static void
 folderlist_tvals_tree_work(struct folderitem *fi, 
                            BOOL suppress_dotfiles, char hiersep,
@@ -528,6 +629,8 @@ folderlist_tvals_tree_work(struct folderitem *fi,
                            int *count, int indent, char *array)
 {
     char *short_name, *s;
+    struct pool *pool = tvals->pool;
+    char *size_str;
 
     while (fi) {
         if ((s=strrchr(fi->name, hiersep)))
@@ -558,6 +661,14 @@ folderlist_tvals_tree_work(struct folderitem *fi,
             if (*count % 2 == 0)
                 template_vals_foreach_ulong(tvals, array, *count,
                                             "even_row", 1);
+            if (fi->size > 0)
+                size_str = pool_printf(pool, "%s MBytes", mbytes(fi->size));
+            else
+                size_str = "0.00 MBytes";
+
+            template_vals_foreach_string(tvals, array, *count,
+                                         "size", size_str);
+
             (*count)++;
         }
         if (fi->child && fi->expanded) {
