@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/html_secure.c,v 1.9 2009/01/18 12:03:15 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/html_secure.c,v 1.11 2010/07/01 17:45:15 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -161,9 +161,9 @@ my_strip_entities(char *src)
             char *t = src+2;
             unsigned long value;
             
-            if (((*t == 'x') || (*t == 'X')) && isxdigit(t[1])) {
+            if (((*t == 'x') || (*t == 'X')) && Uisxdigit(t[1])) {
                 t += 2;
-                while (isxdigit(*t))       /* Decode &#X<hexidecimal>; */
+                while (Uisxdigit(*t))       /* Decode &#X<hexidecimal>; */
                     t++;
                 if (*t == ';') {
                     value = strtoul(src+3, NIL, 16);
@@ -173,8 +173,8 @@ my_strip_entities(char *src)
                         continue;
                     }
                 }
-            } else if (isdigit(*t)) {      
-                while (isdigit(*t))        /* Decode &#<decimal>; */
+            } else if (Uisdigit(*t)) {      
+                while (Uisdigit(*t))        /* Decode &#<decimal>; */
                     t++;
                 if (*t == ';') {
                     value = strtoul(src+2, NIL, 10);
@@ -193,18 +193,15 @@ my_strip_entities(char *src)
 
 /* ====================================================================== */
 
-/* html_secure() *********************************************************
+/* html_secure_old() *****************************************************
  *
  * Generate "secure" version of HTML input, with dangerous tags stripped.
  *      b: Output buffer
  *  input: Input string.
  ************************************************************************/
 
-/* Trashes input => caller has to generate temporary copy.
- * Better way to do this? */
-
-void html_secure(struct session *session, struct buffer *b,
-                 BOOL show_images, char *input)
+static void html_secure_old(struct session *session, struct buffer *b,
+                            BOOL show_images, char *input)
 {
     struct options *options = session->options;
     struct prefs *prefs = options->prefs;
@@ -454,6 +451,25 @@ void html_secure(struct session *session, struct buffer *b,
 
 /* ====================================================================== */
 
+/* html_secure() *********************************************************
+ *
+ * Generate "secure" version of HTML input, with dangerous tags stripped.
+ *      b: Output buffer
+ *  input: Input string.
+ ************************************************************************/
+
+void html_secure(struct session *session, struct buffer *b,
+                 BOOL show_images, char *input)
+{
+    if (html_secure_tidy(session, b, show_images, input))
+        return;
+
+    /* Fall back to original sanitizer if html_secure_tidy fails or disabled */
+    html_secure_old(session, b, show_images, input);
+}
+
+/* ====================================================================== */
+
 /* html_secure_strip_all() ***********************************************
  *
  * Remove all HTML tags from source document, to generate something
