@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/html_secure.h,v 1.2 2008/05/19 15:55:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/html_secure.h,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -6,5 +6,6 @@
 /* Copyright (c) University of Cambridge 2000 - 2008 */
 /* See the file NOTICE for conditions of use and distribution. */
 
-void html_secure(struct session *session, struct buffer *b, char *input);
+void html_secure(struct session *session, struct buffer *b,
+                 BOOL show_images, char *input);
 void html_secure_strip_all(struct buffer *b, char *input);
