@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/prayer_session.h,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/prayer_session.h,v 1.5 2010/07/08 10:20:42 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -40,6 +40,7 @@ extern int errno;               /* just in case */
 #include "stream.h"
 #include "folderlist.h"
 #include "html_secure.h"
+#include "html_secure_tidy.h"
 #include "draft.h"
 #include "msg.h"
 #include "msgmap.h"
@@ -49,6 +50,7 @@ extern int errno;               /* just in case */
 #include "lookup.h"
 #include "role.h"
 #include "dictionary.h"
+#include "display.h"
 #include "prefs.h"
 #include "options.h"
 #include "rfc1522.h"
