@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/prefs.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/prefs.c,v 1.4 2011/07/04 09:37:27 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -407,7 +407,8 @@ prefs_parse_option(struct prefs *prefs, char *line,
     case 'm':
         if (!strcmp(key, "msgs_per_page")) {
             numvalue = atoi(value);
-            if ((numvalue >= 5) && (numvalue <= 50))
+            if ((numvalue >= config->msgs_per_page_min) &&
+                (numvalue <= config->msgs_per_page_max))
                 prefs->msgs_per_page = numvalue;
         } else if (!strcmp(key, "maildir")) {
             value = options_decode(value);
