@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/session_streams.c,v 1.2 2008/05/19 15:55:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/session_streams.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -796,6 +796,7 @@ void session_streams_close(struct session *session)
 {
     struct request *request = session->request;
     struct options *options = session->options;
+    struct prefs *prefs = options->prefs;
     BOOL remove_drafts = NIL;
 
     /* Shut down transfer stream */
@@ -806,6 +807,8 @@ void session_streams_close(struct session *session)
 
     /* Shut down other stream */
     if (session->other_stream) {
+        if (prefs->expunge_on_exit)
+            ml_expunge(session, session->other_stream);
         ml_close(session, session->other_stream);
         session->other_stream = NIL;
     }
@@ -836,6 +839,9 @@ void session_streams_close(struct session *session)
 
     /* Shut down inbox stream, flushing options if dirty (and no prefs stream) */
     if (session->inbox_stream) {
+        if (prefs->expunge_on_exit)
+            ml_expunge(session, session->inbox_stream);
+
         if (options->save)
             session_save_options_and_close_inbox(session);
         else
