@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/wrap.c,v 1.5 2008/05/29 13:20:12 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/wrap.c,v 1.8 2009/04/07 11:14:59 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -444,7 +444,7 @@ wrap_line_html_block(struct session *session,
                 }
             } else if (c == '\t') {
                 new_stop = (new_column / 8) + 1;        /* Next tab stop starts here */
-                new_column = (new_stop * 8) + 1;
+                new_column = (new_stop * 8);
                 s++;
             } else {            /* Space */
                 new_column++;
@@ -468,8 +468,28 @@ wrap_line_html_block(struct session *session,
         }
         column += width;
 
-        if (!strncasecmp(s, "http://", strlen("http://")) ||
-            !strncasecmp(s, "https://", strlen("https://"))) {
+        if ((!strncasecmp(s, "<http://", strlen("<http://")) ||
+             !strncasecmp(s, "<https://", strlen("<https://"))) &&
+            (bytes > strlen("<http://")) && (s[bytes-1] == '>')) {
+            /* Prune leading '<' and trailing '>': add them back by hand */
+            s++;
+            bytes -= 2;
+            
+            t = pool_alloc(b->pool, bytes + 1);
+            memcpy(t, s, bytes);
+            t[bytes] = '\0';
+
+            bprintf(b, "<a target=\"_blank\" href=\"%s\">", t);
+
+            html_quote_char(b, '<');
+            for (i = 0; i < bytes; i++)
+                html_quote_char(b, s[i]);
+            html_quote_char(b, '>');
+            bputs(b, "</a>");
+
+            s += bytes + 1;
+        } else if (!strncasecmp(s, "http://", strlen("http://")) ||
+                   !strncasecmp(s, "https://", strlen("https://"))) {
             /* Quietly remove trailing '.' or ',' from URL */
             BOOL add_trailing = NIL;
 
@@ -482,7 +502,6 @@ wrap_line_html_block(struct session *session,
             memcpy(t, s, bytes);
             t[bytes] = '\0';
 
-            /* No more /redirect links */
             bprintf(b, "<a target=\"_blank\" href=\"%s\">", t);
 
             for (i = 0; i < bytes; i++)
