@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.10 2009/10/16 15:03:00 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.12 2012/06/30 14:30:08 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -152,6 +152,8 @@ struct config *config_create(void)
     config->static_expire_timeout = (7 * 24 * 60 * 60);   /* 7 days  */
     config->socket_dir = NIL;
     config->socket_split_dir = NIL;
+    config->ssl_cipher_list = NIL;
+    config->ssl_server_preference = NIL;
     config->ssl_session_dir = NIL;
     config->lock_dir = NIL;
     config->log_dir = NIL;
@@ -672,6 +674,8 @@ static struct {
     , {
     "ssl_cert_file", config_path, OFFSET(ssl_cert_file)}
     , {
+    "ssl_cipher_list", config_string, OFFSET(ssl_cipher_list)}
+    , {
     "ssl_default_port", config_number, OFFSET(ssl_default_port)}
     , {
     "ssl_dh_file", config_path, OFFSET(ssl_dh_file)}
@@ -688,6 +692,8 @@ static struct {
     , {
     "ssl_rsakey_lifespan", config_time, OFFSET(ssl_rsakey_lifespan)}
     , {
+    "ssl_server_preference", config_bool, OFFSET(ssl_server_preference)}
+    , {
     "ssl_session_dir", config_path, OFFSET(ssl_session_dir)}
     , {
     "ssl_session_timeout", config_time, OFFSET(ssl_session_timeout)}
@@ -2284,7 +2290,7 @@ BOOL config_check(struct config * config)
 
     TEST_NUMBER(config->http_max_method_size, "http_max_method_size");
     TEST_NUMBER(config->http_max_hdr_size, "http_max_hdr_size");
-    TEST_NUMBER(config->http_max_body_size, "http_min_servers");
+    TEST_NUMBER(config->http_max_body_size, "http_max_body_size");
 
     if (!(config->http_port_list && config->http_port_list->head)) {
         config_paniclog(config, "config: No HTTP or HTTPS ports defined");
@@ -2836,6 +2842,8 @@ BOOL config_mkdirs(struct config * config)
 void
 config_extract_ssl(struct config *src, struct ssl_config *dst)
 {
+    dst->ssl_cipher_list       = src->ssl_cipher_list;
+    dst->ssl_server_preference = src->ssl_server_preference;
     dst->ssl_session_dir      = src->ssl_session_dir;
     dst->ssl_cert_file        = src->ssl_cert_file;
     dst->ssl_privatekey_file  = src->ssl_privatekey_file;
