@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/shared/response.c,v 1.6 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/shared/response.c,v 1.8 2009/11/17 11:47:14 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -552,11 +552,14 @@ response_raw(struct request *request, char *name, char *type,
             name = s + 1;
 
         /* Replace " characters from name to prevent quoting problems */
+        /* Tab characters cause problems for MSIE */
         name = pool_strdup(request->pool, name);
 
         for (s = name; *s; s++) {
             if (*s == '"')
                 *s = '_';
+            if (*s == '\t')
+                *s = '_';
         }
     } else
         name = "unknown";
@@ -576,11 +579,10 @@ response_raw(struct request *request, char *name, char *type,
         response_header_start(request, status);
         bputs(b, "Content-Transfer-Encoding: binary" CRLF);
 
-        /* Stolen from Squirelmail: try to force download */
-        /* MSIE can't cope with quotes in Content- headers? */
-        bprintf(b, "Content-Disposition: inline; filename=%s" CRLF, name);
-        bprintf(b, "Content-Type: application/download; name=%s" CRLF,
-                name);
+        /* Stolen from IMP */
+        bprintf(b, "Content-Type: application/x-msdownload" CRLF);
+        bprintf(b, "Content-Disposition: attachment; filename=\"%s\"" CRLF,
+                string_url_encode(request->pool, name));
 
         /* MSIE can't cope with download links which expire immediately? */
         bputs(b, "Expires: ");
