@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/shared/user_agent.c,v 1.4 2009/08/20 14:28:23 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/shared/user_agent.c,v 1.5 2009/09/28 15:05:13 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -321,6 +321,24 @@ void user_agent_setup_browser(struct user_agent *ua, char *browser)
 
     /* Mozilla */
     if (!strncasecmp(browser, "Mozilla/5", strlen("Mozilla/5"))) {
+        /* Grr. Daft User-agent strings:
+         *
+         * Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; en-us)
+         * AppleWebKit/531.9 (KHTML, like Gecko) Version/4.0.3 Safari/531.9
+         */
+ 
+        if (strstr(browser, " AppleWebKit/") ||
+            strstr(browser, " Safari/")) {
+            ua->use_icons = T;
+            ua->use_cookie = T;
+            ua->use_http_1_1 = T;
+            ua->use_pipelining = NIL;
+            /* Problems with persistent connections after file upload */
+            ua->use_persist = NIL;
+            ua->use_gzip = T;
+            return;
+        }
+
         ua->use_icons = T;
         ua->use_cookie = T;
         ua->use_http_1_1 = T;
